#!/usr/bin/env node
var fs = require('fs');
    sys = require('sys'),
    path = require('path'),
    showdown = require('./showdown'),
    _ = require('underscore'),
    argv = process.argv.slice(2, process.argv.length);

var index = _.template(fs.readFileSync(__dirname + '/templates/index.html', 'utf-8')),
    doc = _.template(fs.readFileSync(  __dirname + '/templates/doc.html', 'utf-8')),
    stylesheet = fs.readFileSync(      __dirname + '/templates/style.css', 'utf-8');

var package = {},
    readme = '';

try {
    package = JSON.parse(fs.readFileSync('package.json', 'utf-8'));
} catch(e) {
    console.error('ERROR: Trouble reading package.json');
    process.exit(1);
}

try {
    readme = showdown.encode(fs.readFileSync('README.md', 'utf-8'));
} catch(e) {
    console.error('README.md not found');
}

try {
    var docPages = fs.readdirSync('doc').map(function(f) {
        return f.replace('.md', '.html');
    });

    fs.readdirSync('doc').map(function(f) {
        var docHtml = showdown.encode(fs.readFileSync('doc/' + f, 'utf-8'));
        fs.writeFileSync('_site/doc/' + f.replace('.md', '.html'), doc({
            name: package.name,
            version: package.version,
            authorName: package.author.name ? package.author.name : package.author,
            authorUrl: package.author.url,
            year: (new Date()).getFullYear(),
            description: package.description,
            title: package.name +
                (package.description ? ' - ' + package.description : ''),
            doc: docHtml
        }), 'utf-8');
    });
} catch(e) {
    console.log('doc/ not found');
}

var indexHtml = index({
    name: package.name,
    version: package.version,
    authorName: package.author.name ? package.author.name : package.author,
    authorUrl: package.author.url,
    docPages: docPages,
    licenses: package.licenses,
    contributors: package.contributors,
    year: (new Date()).getFullYear(),
    description: package.description,
    title: package.name +
        (package.description ? ' - ' + package.description : ''),
    readme: readme
})

try { fs.mkdirSync('_site', 0777); } catch(e) {}
try { fs.mkdirSync('_site/doc', 0777); } catch(e) {}

fs.writeFileSync('_site/index.html', indexHtml, 'utf-8');
fs.writeFileSync('_site/style.css', stylesheet, 'utf-8');


